@@ -9,17 +9,17 @@ def parse_args() -> argparse.Namespace:
         description="Create and view a graph representation of a social network.")
     parser.add_argument(
         "-n",
-        type=str,
-        help="label of the column containing the name (default: 'name')",
-        metavar="LABEL",
-        default="name"
+        type=int,
+        help="number of the column containing the name (default: 0)",
+        metavar="COLUMN",
+        default=0
     )
     parser.add_argument(
         "-c",
-        type=str,
-        help="label of the column containing the connections (default: 'connections')",
-        metavar="LABEL",
-        default="connections"
+        type=int,
+        help="number of the column containing the connections (default: 1)",
+        metavar="COLUMN",
+        default=1
     )
     parser.add_argument(
         "-o",
@@ -29,8 +29,8 @@ def parse_args() -> argparse.Namespace:
         default="graph.svg"
     )
     parser.add_argument(
-        "-v",
-        help="enable verbose logging",
+        "-q",
+        help="stop logging to stdout",
         action="store_true"
     )
     parser.add_argument(
@@ -39,5 +39,11 @@ def parse_args() -> argparse.Namespace:
         help="tab separated values file",
         metavar="SPREADSHEET"
     )
+    parser.add_argument(
+        "-v",
+        "--view",
+        help="view the output using default system tool",
+        action="store_true"
+	)
     args = parser.parse_args()
     return args
